(***********************************************************************)
(*                                                                     *)
(*                              Ref-image                              *)
(*                                                                     *)
(*                  Image Segmentation by Refinement                   *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2009-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: ugen_numbering_hashtbl_print.ml,v 1.7 2014-01-21 17:17:21 fclement Exp $*)

(* Generic numbering hash table printers. *)

open Ugen_numbering_hashtbl;;

let pprint_value pp_a = Uindex_print.print_t pp_a;;

let pprint_entry pp_key pp_key_value h ppf k _v =
  Format.fprintf ppf "@ @[%a ->@ %a@]" pp_key k pp_key_value (h k);
;;

let pprint_h pp_key pp_key_value ppf t =
  Format.fprintf ppf "%a"
    (fun ppf -> iter (pprint_entry pp_key pp_key_value t.h ppf))
    t
;;

let pprint_entry_inv pp_key pp_key_value h_inv ppf _k v =
  Format.fprintf ppf "@ @[%a ->@ %a@]" pp_key_value v pp_key (h_inv v);
;;

let pprint_h_inv pp_key pp_key_value ppf t =
  Format.fprintf ppf "%a"
    (fun ppf -> iter (pprint_entry_inv pp_key pp_key_value t.h_inv ppf))
    t
;;

let pprint_t pp_size pp_key ppf ({ length = u_l; size = s; _; } as t) =
  let pp_key_value = pprint_value pp_key in
  Format.fprintf ppf "@[<2>{ @,";
  Format.fprintf ppf "@[<1>length =@ ";
    Upervasives_print.print_length ppf u_l;
    Format.fprintf ppf ";@]@ ";
  Format.fprintf ppf "@[<1>size =@ ";
    pp_size ppf s;
    Format.fprintf ppf ";@]@ ";
  Format.fprintf ppf "@[<hv 2>h : key -> value =";
    pprint_h pp_key pp_key_value ppf t;
    Format.fprintf ppf ";@]@ ";
  Format.fprintf ppf "@[<hv 2>h_inv : value -> key =";
    pprint_h_inv pp_key pp_key_value ppf t;
    Format.fprintf ppf ";@]@ ";
  Format.fprintf ppf "@, }@]";
;;

let print_value pp_a = pprint_value pp_a;;
let print_t pp_size = pprint_t pp_size;;
