(***********************************************************************)
(*                                                                     *)
(*                              Ref-image                              *)
(*                                                                     *)
(*                  Image Segmentation by Refinement                   *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2009-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: display_quantity_rc.mli,v 1.10 2014-02-26 00:12:42 fclement Exp $ *)

open Segmentation_types;;
open Configuration_types;;
open Display_types;;

(** {3 Rgb_compounds} *)

val blank : color;;

(** {6 Pixmaps} *)

val make_pixmaps :
  quantity -> graphics_kind -> display_image_size -> pixmaps
;;

(** {6 Lower left corners} *)

val make_lower_left_corners :
  quantity ->
  graphics_kind -> rgb_direction -> display_image_size -> length ->
  lower_left_corners
;;

(** {6 Print_pixmaps} *)

val fake_print_pixmaps : print_pixmaps;;

val make_print_pixmaps :
  quantity -> pixmaps -> graphics_kind -> print_pixmaps
;;

(** {6 Alter_pixmaps} *)

val fake_alter_pixmaps : ('a, 'b) alter_pixmaps;;

val make_alter_pixmaps :
  quantity ->
  (color -> color) -> ('a -> 'a -> 'a) -> pixmaps -> graphics_kind ->
  ('a, 'b) alter_pixmaps
;;

(** {6 Draw_pixmaps} *)

val fake_draw_pixmaps : draw_pixmaps;;

val make_draw_pixmaps :
  quantity -> pixmaps -> lower_left_corners -> graphics_kind ->
  draw_pixmaps
;;

(** {6 Application} *)

val alter_apply :
  ('a, 'b) pixmap_iter -> 'a colormap Tuple.Triple.t ->
  'a gimage Tuple.Triple.t -> ('a, 'b) pimage Tuple.Triple.t ->
  ('a, 'b) alter_pixmaps -> unit
;;

val draw_apply : draw_pixmaps -> unit;;

val print_apply :
  (print_pixmap -> Format.formatter -> unit) -> Format.formatter ->
  print_pixmaps -> unit
;;
