(***********************************************************************)
(*                                                                     *)
(*                              Ref-image                              *)
(*                                                                     *)
(*                  Image Segmentation by Refinement                   *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2009-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* Beginning of OCamlGen, 3.3+dev4 generated code *)

open Segmentation_types_print;;

let print_aspect ppf = function
  | Display_types.Portrait -> Format.fprintf ppf "%s" "Portrait"
  | Display_types.Landscape -> Format.fprintf ppf "%s" "Landscape"
;;

let print_direction ppf = function
  | Display_types.Horizontal -> Format.fprintf ppf "%s" "Horizontal"
  | Display_types.Vertical -> Format.fprintf ppf "%s" "Vertical"
;;

let print_rgb_direction ppf = function
  | Display_types.Rgb_Horizontal -> Format.fprintf ppf "%s" "Rgb_Horizontal"
  | Display_types.Rgb_Vertical -> Format.fprintf ppf "%s" "Rgb_Vertical"
;;

let rec print_image_size ppf = function | s -> print_size ppf s

and print_display_image_size ppf = function | s -> print_size ppf s

and print_window_size ppf = function | s -> print_size ppf s

and print_min_window_size ppf = function | w -> print_window_size ppf w

and print_max_window_size ppf = function | w -> print_window_size ppf w
;;

let print_scaling_factor ppf = function
  | u_t -> Upositive_rational_print.print_t ppf u_t
;;

let print_scaling ppf = function
  | f_u_t_u_t ->
    Lib_print.print_fun Unatural_print.print_t Unatural_print.print_t ppf
     f_u_t_u_t
;;

let print_graphics_elements ppf = function
  | {
      Display_types.rgb_direction = r;
      Display_types.scaling_factor = s;
      Display_types.display_image_size = d;
      Display_types.window_size = w;
    } ->
    Format.fprintf ppf "%,@[<1>{@,";
    Format.fprintf ppf "%,@[<1>rgb_direction =@ "; print_rgb_direction ppf r;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>scaling_factor =@ ";
    print_scaling_factor ppf s; Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>display_image_size =@ ";
    print_display_image_size ppf d; Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>window_size =@ "; print_window_size ppf w;
    Format.fprintf ppf "%,;@]@ "; Format.fprintf ppf "%,@,}@]"
;;

let print_quantity ppf = function
  | Display_types.Param -> Format.fprintf ppf "%s" "Param"
  | Display_types.Data -> Format.fprintf ppf "%s" "Data"
  | Display_types.Grad -> Format.fprintf ppf "%s" "Grad"
;;

let print_rgb_compound pp_a ppf = function
  | { Display_types.rgb = (a, a0, a1); Display_types.compound = a2; } ->
    Format.fprintf ppf "%,@[<1>{@,"; Format.fprintf ppf "%,@[<1>rgb =@ ";
    Format.fprintf ppf "%,@[<1>(@,"; pp_a ppf a; Format.fprintf ppf "%,,@ ";
    pp_a ppf a0; Format.fprintf ppf "%,,@ "; pp_a ppf a1;
    Format.fprintf ppf "%,@,)@]"; Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>compound =@ "; pp_a ppf a2;
    Format.fprintf ppf "%,;@]@ "; Format.fprintf ppf "%,@,}@]"
;;

let print_pixmap_iter pp_a pp_b ppf = function
  | f_f_z_f_a_z_u_f_a_b_p_u ->
    Lib_print.print_fun
     (Lib_print.print_fun print_zone_number
       (Lib_print.print_fun (print_zc_gimage pp_a) Lib_print.print_unit)
     ) (Lib_print.print_fun (print_pimage pp_a pp_b) Lib_print.print_unit)
     ppf f_f_z_f_a_z_u_f_a_b_p_u

and print_colormap pp_a ppf = function
  | f_f_c_c_f_a_c ->
    Lib_print.print_fun (Lib_print.print_fun print_color print_color)
     (Lib_print.print_fun pp_a print_color) ppf f_f_c_c_f_a_c
;;

let print_pixmap ppf = function
  | g_p -> Generic_image_print.print_pixmap ppf g_p

and print_lower_left_corner ppf = function | p -> print_point ppf p

and print_print_pixmap ppf = function
  | f_f_f_u ->
    Lib_print.print_fun Format_print.print_formatter Lib_print.print_unit ppf
     f_f_f_u

and print_alter_pixmap pp_a pp_b ppf = function
  | f_a_b_p_f_a_c_f_a_g_f_a_b_p_u ->
    Lib_print.print_fun (print_pixmap_iter pp_a pp_b)
     (Lib_print.print_fun (print_colormap pp_a)
       (Lib_print.print_fun (print_gimage pp_a)
         (Lib_print.print_fun (print_pimage pp_a pp_b) Lib_print.print_unit)
       )
     ) ppf f_a_b_p_f_a_c_f_a_g_f_a_b_p_u

and print_draw_pixmap ppf = function
  | f_u_u ->
    Lib_print.print_fun Lib_print.print_unit Lib_print.print_unit ppf f_u_u
;;

let print_pixmaps ppf = function
  | p_r -> print_rgb_compound print_pixmap ppf p_r

and print_lower_left_corners ppf = function
  | l_r -> print_rgb_compound print_lower_left_corner ppf l_r

and print_print_pixmaps ppf = function
  | p_r -> print_rgb_compound print_print_pixmap ppf p_r

and print_alter_pixmaps pp_a pp_b ppf = function
  | a_b_a_r -> print_rgb_compound (print_alter_pixmap pp_a pp_b) ppf a_b_a_r

and print_draw_pixmaps ppf = function
  | d_r -> print_rgb_compound print_draw_pixmap ppf d_r
;;

let print_display_quantity pp_a pp_b ppf = function
  | {
      Display_types.print_pixmaps = p;
      Display_types.alter_pixmaps = a_b_a;
      Display_types.draw_pixmaps = d;
    } ->
    Format.fprintf ppf "%,@[<1>{@,";
    Format.fprintf ppf "%,@[<1>print_pixmaps =@ "; print_print_pixmaps ppf p;
    Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>alter_pixmaps =@ ";
    print_alter_pixmaps pp_a pp_b ppf a_b_a; Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>draw_pixmaps =@ "; print_draw_pixmaps ppf d;
    Format.fprintf ppf "%,;@]@ "; Format.fprintf ppf "%,@,}@]"
;;

let print_display_quantities pp_a pp_b ppf = function
  | {
      Display_types.dq_param = a_b_d;
      Display_types.dq_data = a_b_d0;
      Display_types.dq_grad = a_b_d1;
    } ->
    Format.fprintf ppf "%,@[<1>{@,";
    Format.fprintf ppf "%,@[<1>dq_param =@ ";
    print_display_quantity pp_a pp_b ppf a_b_d; Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>dq_data =@ ";
    print_display_quantity pp_a pp_b ppf a_b_d0;
    Format.fprintf ppf "%,;@]@ "; Format.fprintf ppf "%,@[<1>dq_grad =@ ";
    print_display_quantity pp_a pp_b ppf a_b_d1;
    Format.fprintf ppf "%,;@]@ "; Format.fprintf ppf "%,@,}@]"
;;

(* End of OCamlGen, 3.3+dev4 generated code *)
