(***********************************************************************)
(*                                                                     *)
(*                                Ulib                                 *)
(*                                                                     *)
(*                   OCaml user's additional library                   *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2004-2013 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: ustructural_mapping.ml,v 1.1 2013/06/26 17:29:48 fclement Exp $ *)

(* Structural mappings. *)

type block_number = Udelayed_graph.arrow_number;;

type ('a, 'b, 'c) block = (('a, 'b) Ugraph.t, 'c) Udelayed_graph.arrow;;

type ('a, 'b, 'c) t = (('a, 'b) Ugraph.t, 'c) Udelayed_graph.t;;

let get sm blk_nb = Udelayed_graph.get sm blk_nb
and set sm blk_nb g = Udelayed_graph.set sm blk_nb g
and set_next sm g = Udelayed_graph.set_next sm g
;;

let same sm1 sm2 = Udelayed_graph.same sm1 sm2;;

(* Converters. *)

let sm_choice sm =
  let { Udelayed_graph.value = map; _; } =
    Udelayed_graph.get sm Unatural._0_ in
  match map.Ugraph.images with
  | Ugraph.Constant y -> y
  | Ugraph.Images ims -> ims.(0)
;;

let images_of_sm sm dom =
  let y0 = sm_choice sm in
  let ims = Uarray.make (Unonempty_set.cardinal dom) y0 in
  let f_item { Udelayed_graph.value = map; _; } =
    match map with
    | { Ugraph.domain = item_dom; images = Ugraph.Constant item_y; } ->
        let f item_uindex =
          let index =
            Uuniverse.index dom.Unonempty_set.uindices item_uindex in
          ims.(Uindex.to_int index) <- item_y in
        Unonempty_set.iter f item_dom
    | { Ugraph.domain = item_dom; images = Ugraph.Images item_ims; } ->
        let f item_index item_uindex =
          let index =
            Uuniverse.index dom.Unonempty_set.uindices item_uindex in
          ims.(Uindex.to_int index) <- item_ims.(Uindex.to_int item_index) in
        Unonempty_set.iter_i f item_dom in
  Ustamped_darray.iter f_item sm.Udelayed_graph.graph;
  ims
;;

let gen_to_graph dom_of sm =
  let dom = dom_of sm in
  let ims = images_of_sm sm dom in
  Ugraph.from_array dom ims
;;

let full_domain_of_sm mg =
  let { Udelayed_graph.value = map; _; } =
    Udelayed_graph.get mg Unatural._0_ in
  let u = map.Ugraph.domain.Unonempty_set.universe in
  Unonempty_set.full u
;;

let to_graph sm = gen_to_graph full_domain_of_sm sm;;

let of_graph f g = Udelayed_graph.make f Unatural._1_ g;;

(* Iterators. *)

let fold_left_i = Udelayed_graph.fold_left_i;;
